@@ -4,8 +4,8 @@ knitr::opts_chunk$set(
   comment = "#>"
 )
 
-## ----echo=F, out.width = "50%"------------------------------------------------
-knitr::include_graphics("../man/figure/example.png")
+## ----echo=F, out.width = "90%"------------------------------------------------
+knitr::include_graphics("../man/figure/conbine_1.png")
 
 ## ----echo=F, out.width = "100%"-----------------------------------------------
 knitr::include_graphics("../man/figure/motif_motify.png")
